fnss.adapters.ns2.validate_ns2_stacks — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.adapters.ns2.validate_ns2_stacks

`validate_ns2_stacks`(topology)

  Validate whether the stacks and applications of a topology are valid for ns-2 deployment

  Parameters : | topology : Topology The topology object to validate
  Returns : | valid : bool True if stacks are valid ns-2 stacks, False otherwise

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »